==> estateplat-common-1.2.3-20180706.080354-139-sources.jar: cn/gtmap/estateplat/model/exchange/court/GxPeKzjg.java <==
package cn.gtmap.estateplat.model.exchange.court;

import javax.persistence.Id;
import javax.persistence.Table;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2018/6/27
 * @description
 */
@Table(name = "gx_pe_kzjg")
public class GxPeKzjg {
    @Id
    private String id;//主键id
    private String cxqqdh;//控制请求单号
    private String bdcdyh;//不动产单元号
    private String bdcqzh;//不动产权证号
    private String kzzt;//控制结果
    private String csksrq;//措施始期，格式：2015/08/14
    private String csjsrq;//措施终期，格式：2018/08/14
    private String wnkzyy;//未能控制原因
    private String beiz;//备注
    private String kzcs;//控制措施

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCxqqdh() {
        return cxqqdh;
    }

    public void setCxqqdh(String cxqqdh) {
        this.cxqqdh = cxqqdh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getKzzt() {
        return kzzt;
    }

    public void setKzzt(String kzzt) {
        this.kzzt = kzzt;
    }

    public String getCsksrq() {
        return csksrq;
    }

    public void setCsksrq(String csksrq) {
        this.csksrq = csksrq;
    }

    public String getCsjsrq() {
        return csjsrq;
    }

    public void setCsjsrq(String csjsrq) {
        this.csjsrq = csjsrq;
    }

    public String getWnkzyy() {
        return wnkzyy;
    }

    public void setWnkzyy(String wnkzyy) {
        this.wnkzyy = wnkzyy;
    }

    public String getBeiz() {
        return beiz;
    }

    public void setBeiz(String beiz) {
        this.beiz = beiz;
    }

    public String getKzcs() {
        return kzcs;
    }

    public void setKzcs(String kzcs) {
        this.kzcs = kzcs;
    }
}

==> estateplat-common-1.2.3-20180707.012755-142-sources.jar: cn/gtmap/estateplat/model/exchange/court/GxPeKzjg.java <==
package cn.gtmap.estateplat.model.exchange.court;

import javax.persistence.Id;
import javax.persistence.Table;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2018/6/27
 * @description
 */
@Table(name = "gx_pe_kzjg")
public class GxPeKzjg {
    @Id
    private String id;//主键id
    private String cxqqdh;//控制请求单号
    private String bdcdyh;//不动产单元号
    private String bdcqzh;//不动产权证号
    private String kzzt;//控制结果
    private String csksrq;//措施始期，格式：2015/08/14
    private String csjsrq;//措施终期，格式：2018/08/14
    private String wnkzyy;//未能控制原因
    private String beiz;//备注
    private String kzcs;//控制措施

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCxqqdh() {
        return cxqqdh;
    }

    public void setCxqqdh(String cxqqdh) {
        this.cxqqdh = cxqqdh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getKzzt() {
        return kzzt;
    }

    public void setKzzt(String kzzt) {
        this.kzzt = kzzt;
    }

    public String getCsksrq() {
        return csksrq;
    }

    public void setCsksrq(String csksrq) {
        this.csksrq = csksrq;
    }

    public String getCsjsrq() {
        return csjsrq;
    }

    public void setCsjsrq(String cxjsrq) {
        this.csjsrq = csjsrq;
    }

    public String getWnkzyy() {
        return wnkzyy;
    }

    public void setWnkzyy(String wnkzyy) {
        this.wnkzyy = wnkzyy;
    }

    public String getBeiz() {
        return beiz;
    }

    public void setBeiz(String beiz) {
        this.beiz = beiz;
    }

    public String getKzcs() {
        return kzcs;
    }

    public void setKzcs(String kzcs) {
        this.kzcs = kzcs;
    }
}
